package data.missions.balance_demo;

import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin {

	public void defineMission(MissionDefinitionAPI api) {

		// Set up the fleets so we can add ships and fighter wings to them.
		// In this scenario, the fleets are attacking each other, but
		// in other scenarios, a fleet may be defending or trying to escape
		api.initFleet(FleetSide.PLAYER, "BAL_B", FleetGoal.ATTACK, false);
		api.initFleet(FleetSide.ENEMY, "BAL_A", FleetGoal.ATTACK, true);

		// Set a small blurb for each fleet that shows up on the mission detail and
		// mission results screens to identify each side.
		api.setFleetTagline(FleetSide.PLAYER, "'Balance B ships.  IR Pulse Lasers.'");
		api.setFleetTagline(FleetSide.ENEMY, "Balance A ships.  Tac Lasers.");
		
		// These show up as items in the bulleted list under 
		// "Tactical Objectives" on the mission detail screen
		//api.addBriefingItem("Show 'High Rad' Moon what it means to break a deal.");
		//api.addBriefingItem("Don't lose 'Stranger II' - it's my most valuable possession.");
		//api.addBriefingItem("Moon's ship has delicate engine mods; use Salamander Missiles to leave her adrift");
		
		// Set up the player's fleet.  Variant names come from the
		// files in data/variants and data/variants/fighters
		for(int i=0; i<10; i++){
			api.addToFleet(FleetSide.PLAYER, "balance_b_variant", FleetMemberType.SHIP, "Balance B", false);
		}
		// Set up the enemy fleet.
		for(int i=0; i<10; i++){
			api.addToFleet(FleetSide.ENEMY, "balance_a_variant", FleetMemberType.SHIP, "Balance A", false);
		}
		
		//api.defeatOnShipLoss("Stranger II");
		
		// Set up the map.
		float width = 12000f;
		float height = 12000f;
		api.initMap((float)-width/2f, (float)width/2f, (float)-height/2f, (float)height/2f);
		
		float minX = -width/2;
		float minY = -height/2;
		
		// Add an asteroid field
		//api.addAsteroidField(minX, minY + height / 2, 0, 8000f, 20f, 70f, 100);
		
		//api.addPlanet(0, 0, 50f, "star_red", 250f, true);
		
	}

}
